from typing import List, Optional

from sqlalchemy.orm import Session

from app.crud.base import CRUDBase
from app.models.tag import Tag
from app.schemas.tag import TagCreate, TagUpdate


class CRUDTag(CRUDBase[Tag, TagCreate, TagUpdate]):
    def get_by_name(self, db: Session, *, name: str) -> Optional[Tag]:
        return db.query(Tag).filter(Tag.name == name).first()

    def get_multi_by_names(
        self, db: Session, *, names: List[str]
    ) -> List[Tag]:
        return db.query(Tag).filter(Tag.name.in_(names)).all()


tag = CRUDTag(Tag)